<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
				xmlns:marc="http://www.loc.gov/MARC21/slim"
				xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
				xmlns:dc="http://purl.org/dc/elements/1.1/"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
            	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
            	xmlns:dcterms="http://purl.org/dc/terms/"
				exclude-result-prefixes="marc dcterms rdf">

<xsl:output method="xml" indent="yes" omit-xml-declaration="yes" encoding="UTF-8"/>

<xsl:param name="WEB_ROOT" />
<xsl:param name="WEB_ROOT_I18N" />
<xsl:param name="driver" />
<xsl:param name="anyo_defecto" />
<xsl:param name="decada_defecto" />
<xsl:param name="generar_enlaces_ficha" select="true()"/>
<xsl:param name="generar_enlaces_grupos" select="false()" />
<xsl:param name="web" />	<!-- Equivalente con la anterior, se mantiene slo por compatibilidad -->
<xsl:param name="provider" />
<xsl:param name="idOai" />


<xsl:variable name="EDM" select="false()" />
<xsl:variable name="DC_CUALIFICADO" select="false()" />

<xsl:variable name="nodos_estructura_campos" select="document('../datos_campos/bib_campos.xml')/*/estructura_campo" />
<xsl:variable name="correspondencia_idioma" select="document('../datos_campos/codigos_idiomas_iso639_2.xml')/*" />

<!-- Se saca la url sin idioma -->
<xsl:variable name="URL_BASE">
    <xsl:variable name="ultimo_trozo_idioma">
        <xsl:value-of select="substring-after(substring($WEB_ROOT,string-length($WEB_ROOT)-4,string-length($WEB_ROOT)),'/')"/>
    </xsl:variable>
    <xsl:choose>
        <xsl:when test="string-length($ultimo_trozo_idioma)>0">
            <xsl:call-template name="replace">
                <xsl:with-param name="texto" select="$WEB_ROOT" />
                <xsl:with-param name="cadena1" select="$ultimo_trozo_idioma" />
                <xsl:with-param name="cadena2" select="''" />
            </xsl:call-template>        
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$WEB_ROOT"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:variable>


<xsl:template name="registro_bib_dc">
	<xsl:param name="nodo_plantilla" />
    <xsl:param name="holdings"/>
    <xsl:param name="europeana" />
    <xsl:param name="linked_data"/>
	
	<xsl:variable name="leader" select="marc:leader"/>
	<xsl:variable name="leader6" select="substring($leader,7,1)"/>
	<xsl:variable name="leader7" select="substring($leader,8,1)"/>
	<xsl:variable name="controlField008" select="marc:controlfield[@tag=008]"/>
    
    <xsl:variable name="fecha260" select="marc:datafield[@tag='260']/marc:subfield[@code='c']"/>
    <xsl:variable name="fecha008">
       <xsl:call-template name="obtener_fecha_008"/>
    </xsl:variable>    

    <xsl:variable name="fecha008primera" select="substring(marc:controlfield[@tag=008],8,4)" />
    <xsl:variable name="fecha008segunda" select="substring(marc:controlfield[@tag=008],12,4)" />
    <xsl:variable name="tipoFecha" select="substring(marc:controlfield[@tag=008],7,1)" />
    
    <!-- CON ESTA FORMA DE ORGANIZACIN SE PRETENDE QUE PARA EDM
    PRIMERO SALGAN LOS DCTERMS Y LUEGO LOS DC  -->
    <xsl:for-each select="marc:datafield[@tag=662]">
        <xsl:choose>
            <xsl:when test="$EDM and string-length(normalize-space(./marc:subfield[@code='0']))>0">
                <xsl:variable name="valor_0">
                    <xsl:value-of select="$URL_BASE"/>
                    <xsl:text>aut/</xsl:text>
                    <xsl:value-of select="normalize-space(./marc:subfield[@code='0'])"/>
                </xsl:variable>
                <xsl:if test="string-length(normalize-space($valor_0))>0">            
                    <dcterms:spatial rdf:resource="{$valor_0}" />
                </xsl:if>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="valor_campo_6XX">
                    <xsl:call-template name="valor_link_campo_marc">
                        <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                    </xsl:call-template>    
                </xsl:variable>
                <xsl:if test="$DC_CUALIFICADO and string-length(normalize-space($valor_campo_6XX))>0">
                    <dcterms:spatial>
                        <xsl:value-of select="$valor_campo_6XX" disable-output-escaping="no" />
                    </dcterms:spatial>
                </xsl:if>
                <xsl:if test="not($DC_CUALIFICADO) and string-length(normalize-space($valor_campo_6XX))>0">
                    <dc:subject>
                        <xsl:value-of select="$valor_campo_6XX" disable-output-escaping="no" />
                    </dc:subject>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:for-each>
    
    <!-- Luego la plantilla -->
   	<xsl:call-template name="eol" />
    <xsl:call-template name="procesar_plantilla">
        <xsl:with-param name="nodo_plantilla" select="$nodo_plantilla" />
        <xsl:with-param name="estructura_campos" select="$nodos_estructura_campos" />
        <xsl:with-param name="tipo_def" select="'bib'" />
    </xsl:call-template>
    
    
    <!-- NODO PUBLISHER, en orden de preferencia 
    700a y 710a si en $e = ed.
    260b si tiene algo distinto de s.m. y 008 posicion 7-10 es anterior a 1801
    260f si tiene s.n.-->

    <xsl:variable name="publisher260b" select="normalize-space(marc:datafield[@tag='260']/marc:subfield[@code='b'])"/>
    <xsl:variable name="publisher260f" select="normalize-space(marc:datafield[@tag='260']/marc:subfield[@code='f'])"/>
    
    <xsl:variable name="publisher260b_lower">
       <xsl:call-template name="lowercase">
           <xsl:with-param name="cadena" select="normalize-space(translate($publisher260b, '].:[', ''))"/>
       </xsl:call-template>    
    </xsl:variable>
    <xsl:variable name="publisher260f_lower">
       <xsl:call-template name="lowercase">
           <xsl:with-param name="cadena" select="normalize-space(translate($publisher260f, '].:[', ''))"/>
       </xsl:call-template>    
    </xsl:variable>
    
    <xsl:choose>
        <xsl:when test="string-length($publisher260b_lower)>0 and not(contains($publisher260b_lower,'sn'))">
            <dc:publisher>
                <xsl:value-of select="$publisher260b"/>
            </dc:publisher>
        </xsl:when>
        <xsl:when test="string-length($publisher260f)>0 and contains($publisher260f_lower,'sn')
                and (string-length(normalize-space($fecha008))=0 or (number($fecha008) &lt; 1801))">
            <dc:publisher>
                <xsl:value-of select="$publisher260f"/>                
            </dc:publisher>
        </xsl:when>
    </xsl:choose>

    <xsl:for-each select="marc:datafield[@tag='700' or @tag='710']">
        <xsl:variable name="publisher7XXe" select="normalize-space(./marc:subfield[@code='e'])"/>
        <xsl:variable name="publisher7XXe_lower">
           <xsl:call-template name="lowercase">
               <xsl:with-param name="cadena" select="normalize-space($publisher7XXe)"/>
           </xsl:call-template>    
        </xsl:variable>
        <xsl:if test="contains($publisher7XXe_lower,'ed')">
            <xsl:variable name="publisher7XXa">
                <xsl:call-template name="valor_link_campo_marc">
                    <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                    <xsl:with-param name="subcampos" select="'a'" />
                </xsl:call-template>
            </xsl:variable>

            <!-- Esto es para que no se repita el 7xx con el 260 que se ha puesto -->
            <xsl:if test="$publisher260b!=$publisher7XXa and $publisher260f!=$publisher7XXa">
                <xsl:choose>
                    <!-- Si es EDM es un enlace a entonces lo ponemos como enlace, sino ponemos directamente el valor -->
                    <xsl:when test="$EDM and starts-with($publisher7XXa, 'http://')">
                        <dc:publisher rdf:resource="{$publisher7XXa}" />
                    </xsl:when>
                    <xsl:otherwise>
                        <dc:publisher>
                            <xsl:value-of select="$publisher7XXa"/>
                        </dc:publisher>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:if>        
    </xsl:for-each>
    
    <!-- Fin del campo publisher -->
    
	<!-- Al principio nodo type -->

    <!--  El nodo del type se saca del LDR -->
    <xsl:variable name="tipo_ldr">
        <xsl:call-template name="get_tipo_conocido_ldr">
            <xsl:with-param name="leader6" select="$leader6" />
            <xsl:with-param name="leader7" select="$leader7" />
        </xsl:call-template>
    </xsl:variable>
    <!-- Se sacan tambin los valores del 655, aunque se usar slo si es driver -->
    <xsl:variable name="tipos_655">
        <xsl:call-template name="get_lista_tipos_conocidos_655">
            <xsl:with-param name="tipo_ldr" select="$tipo_ldr" />
            <xsl:with-param name="separador" select="'@'" />
        </xsl:call-template>
    </xsl:variable>
    <!-- Se genera un nodo por cada uno de los grupos que hay en la lista.
    Estos grupos estn separados por un carcter, separador -->
    <xsl:if test="$driver='true'">
        <xsl:call-template name="genera_nodos_type655">
            <xsl:with-param name="tipos_655" select="$tipos_655" />
            <xsl:with-param name="separador" select="'@'" />
        </xsl:call-template>
    </xsl:if>
    
    <!-- Slo se pondr el tipo LDR si no est ya puesto. En caso de que sea
        Other slo se pondr si no hay ningn tipo en el 655 -->
        <!-- Se pasa a minsculas para comprobar si hay coincidencia -->
    <xsl:variable name="tipos_655_lower">
        <xsl:call-template name="lowercase">
            <xsl:with-param name="cadena" select="$tipos_655" />
        </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="tipo_ldr_lower">
        <xsl:call-template name="lowercase">
            <xsl:with-param name="cadena" select="$tipo_ldr" />
        </xsl:call-template>
    </xsl:variable>  
    
    <xsl:variable name="contiene_ldr">
        <xsl:call-template name="comprueba_655_contiene_LDR">
            <xsl:with-param name="tipos_655" select="$tipos_655_lower" />
            <xsl:with-param name="separador" select="'@'" />
            <xsl:with-param name="tipo_ldr" select="$tipo_ldr_lower" />
        </xsl:call-template>                
    </xsl:variable>

    <xsl:variable name="tipo_publicacion_ldr">
        <xsl:call-template name="bib_tipo_publicacion"/>
    </xsl:variable>
    <xsl:choose>
        <!-- Se pone el del campo ldr slo si el 655 est vaco o si no est vaco y no lo contiene y es distinto de other-->
        <!-- Slo se muestra el Other si es driver -->
        <xsl:when test="$tipo_ldr = 'other' and $driver='true' and $europeana!='true' and not($EDM) and
        (
            string-length(normalize-space($tipos_655)) = 0 or 
            (normalize-space($contiene_ldr)='false' and $tipo_ldr != 'other')
        )">
            <dc:type>
                <xsl:choose>
                    <xsl:when test="$tipo_ldr = 'other' and $driver='true'">
                        <xsl:text>book</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$tipo_ldr"/>
                    </xsl:otherwise>
                </xsl:choose>
            </dc:type>
        </xsl:when>
        <xsl:when test="$driver='true' and $europeana!='true' and not($EDM) and 
            string-length(normalize-space($tipos_655)) = 0">
            <dc:type>
                <xsl:value-of select="$tipo_ldr"/>
            </dc:type>
        </xsl:when>
        <!-- Si no es driver, slo se pone la cabecera -->
        <xsl:when test="string-length(normalize-space($tipo_publicacion_ldr))>0 and 
            ($driver!='true' or 
            $driver='true' and string-length(normalize-space($tipos_655)) = 0)">
            <dc:type>
                <xsl:value-of select="normalize-space($tipo_publicacion_ldr)"/>
            </dc:type>
        </xsl:when>
    </xsl:choose>

    
    <!-- Final del nodo type -->    
    
    
	<!-- Nodo language -->
    <!-- Se sacan las lenguas tanto del 008 como del 041 sin repetir ninguna -->
    <!-- Primero del 008 -->
	<xsl:variable name="language" select="substring($controlField008,36,3)" />
    <xsl:choose>
    	<xsl:when test="$language != '|||' and $language != '   ' and $language != '###' and string-length(normalize-space($language))>0">
            <xsl:call-template name="genera_nodos_language">
                <xsl:with-param name="cadena_idiomas" select="$language" />
                <xsl:with-param name="longitud_idioma" select="3" />
                <xsl:with-param name="idiomas_repetidos" select="''" />
                <xsl:with-param name="linked_data" select="$linked_data" />            
                <xsl:with-param name="europeana" select="$europeana" />
            </xsl:call-template>
    	</xsl:when>
        <!-- Si es una lengua vaca devolvemos el valor "und" (undefined) -->
        <xsl:otherwise>
            <dc:language><xsl:text>und</xsl:text></dc:language>
        </xsl:otherwise>
    </xsl:choose>
    <!-- Guardamos todos los idiomas de todos los 041$a en una cadena para generar nodos language a partir
         de todos los idiomas y sin que se repitan entre ellos. Cada idioma se considerar de longitud 3.
         Lo hacemos as en lugar de recorrer cada 041$a para evitar 041$a repetidos. -->
    <xsl:variable name="idiomas_041">
        <xsl:call-template name="valores_campos">
            <xsl:with-param name="tag" select="'041'" />
            <xsl:with-param name="subcampos" select="'a'" />
        	<xsl:with-param name="separador_campos" select="''" />
        </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="genera_nodos_language">
        <xsl:with-param name="cadena_idiomas" select="$idiomas_041" />
        <xsl:with-param name="longitud_idioma" select="3" />
        <xsl:with-param name="idiomas_repetidos" select="$language" />
        <xsl:with-param name="linked_data" select="$linked_data" />            
        <xsl:with-param name="europeana" select="$europeana" />
    </xsl:call-template>
    <xsl:call-template name="eol" />
    <!--  fin del nodo language -->
    
    <!-- Se sacan sin las fechas son vlidas -->
    <xsl:variable name="is_primera_fecha_valida">
        <xsl:call-template name="is_fecha_valida">
            <xsl:with-param name="fecha" select="$fecha008primera"/>
        </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="is_segunda_fecha_valida">
        <xsl:call-template name="is_fecha_valida">
            <xsl:with-param name="fecha" select="$fecha008segunda"/>
        </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="fecha_primera_valida">
        <xsl:call-template name="transformar_fecha_desconocida">
            <xsl:with-param name="fecha" select="$fecha008primera"/>
        </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="fecha_segunda_valida">
        <xsl:call-template name="transformar_fecha_desconocida">
            <xsl:with-param name="fecha" select="$fecha008segunda"/>
        </xsl:call-template>
    </xsl:variable>
    <!-- Comienzo del nodo date. Se distinguir si es cualificado/europeana o no
    Dentro de que no lo sea, se distinguir si es driver o no -->
    <xsl:choose>
        <!-- Si no es europeana y es driver, se saca la fecha del 260c
        transformada. Si no existe, se saca del 008 -->
        <xsl:when test="$europeana!='true' and $driver='true'">
            <xsl:variable name="fecha260_transform" select="normalize-space(translate($fecha260, ' .,;[]()', ''))"/>
    
            <!-- Se obtiene si la fecha es vlida -->            
            <xsl:variable name="fecha_valida">
                <xsl:call-template name="get_fecha_valida">
                    <xsl:with-param name="fecha" select="$fecha260_transform" />
                </xsl:call-template>
            </xsl:variable>
            
            <!--  Si la fecha del 260$c concuerda con alguna de las esperadas se muestra, 
            si no, se saca del 008 -->
            <xsl:choose>
                <xsl:when test="normalize-space($fecha_valida)!='n'">
                    <dc:date>
                        <xsl:value-of select="$fecha_valida"/>
                    </dc:date>
                </xsl:when>
                <xsl:when test="string-length(normalize-space($fecha008))>0">
                    <dc:date>
                        <xsl:value-of select="$fecha008"/>
                    </dc:date>
                </xsl:when>
            </xsl:choose>
        </xsl:when>
        <!-- Si es europeana o no es driver, se comporta de la siguiente manera:
        - Primero se saca del 008, en funcin de si est relleno las posiciones 7-10, 11-14, se muestra
            de una o de otra forma.
        - Si no se ha podido sacar del 008, se saca del 260c de forma especial.
        - Si no se ha sacado del 260c, se saca del 100, 110, 111, 130f
        -->
        <xsl:otherwise>
            <xsl:choose>
                <!-- Primero se mira si es una fecha detallada y el mes/dia vienen bien -->
                <xsl:when test="$is_primera_fecha_valida='true' and $tipoFecha='e' and 
                    string-length(substring($fecha008segunda, 1, 2))=2 and string-length(translate(substring($fecha008segunda, 1, 2),'1234567890',''))=0 and 
                    string-length(substring($fecha008segunda, 3, 2))=2 and string-length(translate(substring($fecha008segunda, 3, 2),'1234567890',''))=0">
                    
                    <xsl:variable name="digitosMes" select="substring($fecha008segunda, 1, 2)" />
                    <xsl:variable name="digitosDia" select="substring($fecha008segunda, 3, 2)" />
                    <dc:date>
                        <xsl:value-of select="$fecha_primera_valida" />
                        <xsl:text>-</xsl:text>
                        <xsl:value-of select="$digitosMes" />
                        <xsl:text>-</xsl:text>
                        <xsl:value-of select="$digitosDia" />
                    </dc:date>
                </xsl:when>
                <!-- Si no es detallada se mira si slo puede ponerse la primera fecha porque la segunda est mal rellena o falte informacin -->
                <xsl:when test="$is_primera_fecha_valida='true' and $is_segunda_fecha_valida!='true'">
                    <dc:date>
                        <xsl:value-of select="$fecha_primera_valida" />
                    </dc:date>
                </xsl:when>
                <!-- Si no es detallada ni se puede poner la primera slo se mira si slo puede ponerse la segunda fecha porque la primera est mal rellena o falte informacin -->                
                <xsl:when test="$is_segunda_fecha_valida='true' and $is_primera_fecha_valida!='true' 
                    and not($tipoFecha='s' or $tipoFecha='u')">
                    <dc:date>
                        <xsl:value-of select="$fecha_segunda_valida" />                    
                    </dc:date>
                </xsl:when>
                <!-- Si se pueden poner ambas fechas porque a ninguna les falte informacin -->                
                <xsl:when test="$is_primera_fecha_valida='true' and $is_segunda_fecha_valida='true'">
                    <dc:date>
                        <xsl:value-of select="$fecha_primera_valida" />
                        <xsl:if test="not($tipoFecha='s' or $tipoFecha='u')">
                            <xsl:text>-</xsl:text>
                            <xsl:value-of select="$fecha_segunda_valida" />
                        </xsl:if>
                    </dc:date>
                </xsl:when>
                <!-- Cualquier otro caso se saca del 260c o 1XX$f -->
                <xsl:otherwise>
                    <xsl:for-each select="marc:datafield[@tag='260']/marc:subfield[@code='c']">
                        <!--  Se le quitan las comas -->            
                        <xsl:variable name="fecha260_sincomas">
                            <xsl:call-template name="replace">
                                <xsl:with-param name="texto" select="." />
                                <xsl:with-param name="cadena1" select="','" />
                                <xsl:with-param name="cadena2" select="''" />
                            </xsl:call-template>
                        </xsl:variable>            
                    
                        <!--  Se eliminan los espacios de la izquierda -->
                        <xsl:variable name="fecha260_sinblancos" select="normalize-space($fecha260_sincomas)"/>
                        <xsl:variable name="fecha260_despues" select="substring-after($fecha260_sincomas, $fecha260_sinblancos)"/>
                        <xsl:variable name="fecha260_sinblancos_delante" select="concat($fecha260_sinblancos,'',$fecha260_despues)"/>
                
                        <!--  Si lo que queda no est vaco se genera nodo date -->
                        <xsl:choose>
                            <xsl:when test="string-length(normalize-space($fecha260_sinblancos_delante)) > 0">
                                <dc:date>
                                    <xsl:value-of select="$fecha260_sinblancos_delante"/>
                                </dc:date>
                            </xsl:when>
                            <xsl:when test="count(marc:datafield[@tag='100' or @tag='110' or @tag='111' or @tag='130']/marc:subfield[@code='f'])>0">
                                <xsl:for-each select="marc:datafield[@tag='100' or @tag='110' or @tag='111' or @tag='130']/marc:subfield[@code='f']">
                                    <dc:date>
                                        <xsl:call-template name="valor_subcampo_marc">
                                            <xsl:with-param name="nodo_subcampo" select="current()" />
                                            <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=../@tag]" />
                                        </xsl:call-template>                                
                                    </dc:date>
                                </xsl:for-each>
                            </xsl:when>
                        </xsl:choose>
                    </xsl:for-each>                
                </xsl:otherwise>
            </xsl:choose>
        </xsl:otherwise>
    </xsl:choose>
   <!--  fin del nodo date -->

    <!-- nodo creator y contributor -->
    <!-- Primero se sacan los creator -->
    <xsl:variable name="nodos_creator" select="marc:datafield[(@tag='100' or @tag='110' or @tag='111'
                            or @tag='700' or @tag='710' or @tag='711' or @tag='720')
                            and (not(marc:subfield[@code='e']) or marc:subfield[@code='e']='aut.' or marc:subfield[@code='e']='coaut.')]" />
    <xsl:for-each select="$nodos_creator">
        <xsl:variable name="norepetido">
            <xsl:call-template name="check_norepetido">
                <xsl:with-param name="nodo_campo" select="." />
            </xsl:call-template>
        </xsl:variable>
        <xsl:if test="$norepetido='OK'">
            <xsl:variable name="_autor">
                <xsl:call-template name="valor_link_campo_marc">
                    <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                    <xsl:with-param name="subcampos" select="'abcde'" />
                </xsl:call-template>
            </xsl:variable>
            <xsl:choose>
                <!-- En EDM lo ponemos como enlace si lo es, sino como valor -->
                <xsl:when test="$EDM and starts-with($_autor, 'http://')">
                    <dc:creator rdf:resource="{$_autor}" />
                </xsl:when>
                <xsl:otherwise>
                    <dc:creator>
                        <xsl:value-of select="$_autor" disable-output-escaping="no" />
                    </dc:creator>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:for-each>
    
    <!-- Ahora se sacan los nodos contributor -->
    <xsl:variable name="nodos_contributor" select="marc:datafield[@tag=700]|marc:datafield[@tag=710]"/>
    <xsl:for-each select="$nodos_contributor">
        <xsl:variable name="valor_e" select="normalize-space(./marc:subfield[@code='e'])"/>
        
        <!--  Cuando el $e sea distinto a los anteriores, ser un contributor -->
        <xsl:if test="string-length($valor_e)>0 and $valor_e != 'aut.' and $valor_e != 'coaut.' and not(contains($valor_e, 'ed'))">
            <xsl:variable name="norepetido">
                <xsl:call-template name="check_norepetido">
                    <xsl:with-param name="nodo_campo" select="." />
                </xsl:call-template>
            </xsl:variable>
            <xsl:if test="$norepetido='OK'">
                <xsl:variable name="_autor">
                    <xsl:call-template name="valor_link_campo_marc">
                        <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                        <xsl:with-param name="subcampos" select="'abcde'" />
                    </xsl:call-template>                
                </xsl:variable>
                <xsl:choose>
                    <!-- En EDM lo ponemos como enlace si lo es, sino como valor -->
                    <xsl:when test="$EDM and starts-with($_autor, 'http://')">
                        <dc:contributor rdf:resource="{$_autor}" />
                    </xsl:when>
                    <xsl:otherwise>
                        <dc:contributor>
                            <xsl:value-of select="$_autor" disable-output-escaping="no" />
                        </dc:contributor>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:if>
    </xsl:for-each>
    
    <!-- Como el nodo creator es obligatorio, si no se ha creado ninguno, para driver, se crea el nodo por defecto -->
    <xsl:if test="$driver='true'">
        <xsl:if test="not(marc:datafield[@tag=100]|marc:datafield[@tag=110]|marc:datafield[@tag=111]|
            marc:datafield[@tag=711] | 
            marc:datafield[(@tag=700 or @tag=710 or @tag=720) and 
                (not(marc:subfield[@code='e']) or marc:subfield[@code='e']='aut.' or marc:subfield[@code='e']='coaut.')])">
            <dc:creator>
                <xsl:text>Anonymous</xsl:text>
            </dc:creator>
        </xsl:if>
    </xsl:if>
    <!-- fin del nodo creator y contributor -->
    
    <!-- Al final un nodo identifier con enlace a la ficha -->
    <xsl:variable name="raiz_url">
        <xsl:value-of select="$WEB_ROOT" />
        <xsl:if test="string-length($WEB_ROOT)=0">
            <xsl:value-of select="$web" />
            <xsl:if test="string-length($web)=0">
                <xsl:text>..</xsl:text>
            </xsl:if>
        </xsl:if>
    </xsl:variable>
    <xsl:variable name="raiz_url_i18n">
        <xsl:value-of select="$WEB_ROOT_I18N" />
        <xsl:if test="string-length($WEB_ROOT_I18N)=0">
            <xsl:value-of select="$web" />
            <xsl:if test="string-length($web)=0">
                <xsl:text>..</xsl:text>
            </xsl:if>
        </xsl:if>
    </xsl:variable>
    <xsl:variable name="id">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'idRegistro'" />
        </xsl:call-template>
    </xsl:variable>
    
    <!-- Se mete en una variable la url de la ficha para sacarla bien por 
    dc o bien por europeana -->
    <xsl:variable name="url_ficha">
        <xsl:if test="string-length($id)">
            <xsl:value-of select="$raiz_url"/>
            <xsl:text>/consulta/registro.cmd?id=</xsl:text>
            <xsl:value-of select="$id"/>
        </xsl:if>
    </xsl:variable>
    
    <xsl:if test="$europeana!='true'">
        <!-- En VB no se le pasa id y por tanto el enlace a la ficha no saldr. Tampoco se sacar
        si es europeana, porque en este caso ya se saca la url con el nodo isShownAt ms abajo -->
        <xsl:if test="string-length($url_ficha) > 0 and $generar_enlaces_ficha=true()">
            <dc:identifier>
                <xsl:value-of select="$url_ficha"/>
            </dc:identifier>
        </xsl:if>
                
        <!-- Nodos identifier adicionales slo si tiene los datos de holdings. Si es europeana, 
        no se sacar este nodo porque ya se mostrar en el nodo isShownBy ms abajo, en donde slo
        se sacar el primer enlace -->
        <xsl:if test="$holdings and $generar_enlaces_grupos=true()">
            <!-- Otro nodo identifier por cada grupo de imgenes -->
            <xsl:for-each select="(. | $holdings)/marc:datafield[@tag='856']/marc:subfield[@code='w']">
                <dc:identifier>
                   <xsl:value-of select="$raiz_url"/>
                   <xsl:text>/catalogo_imagenes/grupo.cmd?path=</xsl:text>
                   <xsl:value-of select="." />
                </dc:identifier>
            </xsl:for-each>
        </xsl:if>
    </xsl:if>
        
    <!-- Se saca el nodo format para imgenes asociadas a holdings -->
    <!-- dc:format -->
    <xsl:variable name='formats' select="(. | $holdings)/marc:datafield[@tag='856']/marc:subfield[@code='q']" />
    <xsl:if test="$linked_data!='true'">
        <xsl:for-each select="$formats">
            <xsl:variable name="positionCurrent" select="position()" />
            <xsl:if test="not($formats[string(.) = string(current()) and (position() &lt; $positionCurrent)])">
                <dc:format>
                   <xsl:value-of select="."/>
                </dc:format>
            </xsl:if>
        </xsl:for-each>
    </xsl:if>
    
    
    <!-- Se sacan los nodos subject -->
    <xsl:for-each select="marc:datafield[@tag=600 or @tag=610 or @tag=611 or @tag=630 or 
            @tag=650 or @tag=651 or @tag=653 or @tag=654 or @tag=655 or @tag=656 or @tag=657 or @tag=658]">

        <!-- Se saca el valor del 655 por si es necesario -->
        <xsl:variable name="type655">
            <xsl:call-template name="get_tipo_version_2">
                <xsl:with-param name="tipo" select="./marc:subfield[@code='a']" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="campo_655_driver">
            <xsl:if test="./@tag=655 and $driver='true'">
                <xsl:call-template name="lowercase">
                    <xsl:with-param name="cadena" select="$type655" />
                </xsl:call-template>
            </xsl:if>
        </xsl:variable>
        
        <xsl:if test="./@tag!=655 or $driver!='true' or not($campo_655_driver = 'article' or $campo_655_driver = 'bachelorthesis' or 
                            $campo_655_driver = 'masterthesis' or $campo_655_driver = 'doctoralthesis' or 
                            $campo_655_driver = 'book' or $campo_655_driver = 'bookpart' or 
                            $campo_655_driver = 'conferenceobject' or $campo_655_driver = 'lecture' or 
                            $campo_655_driver = 'preprint or workingpaper' or $campo_655_driver = 'report' or 
                            $campo_655_driver = 'contributiontoperiodical' or $campo_655_driver = 'review' or 
                            $campo_655_driver = 'annotation' or $campo_655_driver = 'patent')">
            <xsl:choose>
                <xsl:when test="$EDM and string-length(normalize-space(./marc:subfield[@code='0']))>0">
                    <xsl:variable name="valor_0">
                        <xsl:value-of select="$URL_BASE"/>
                        <xsl:text>aut/</xsl:text>
                        <xsl:value-of select="normalize-space(./marc:subfield[@code='0'])"/>
                    </xsl:variable>
                    <xsl:if test="string-length(normalize-space($valor_0))>0">
                        <dc:subject rdf:resource="{$valor_0}" />
                    </xsl:if>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="valor_campo_6XX">
                        <xsl:call-template name="valor_link_campo_marc">
                            <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                        </xsl:call-template>    
                    </xsl:variable>
                    <xsl:if test="string-length(normalize-space($valor_campo_6XX))>0">
                        <dc:subject>
                            <xsl:value-of select="$valor_campo_6XX" disable-output-escaping="no" />
                        </dc:subject>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:for-each>
    
    <!-- Nodo derechos, gestin especial -->
    <xsl:call-template name="generar_nodos_derechos"/>
</xsl:template>

<!-- Aade los nodos de derechos. Primero se intenta sacar de la gestin de sentencias. En caso de que no haya 
gestin de sentencias se saca de los campos 542, 506, 540.
De la gestin de sentencias, vendrn variables cuyo valor ser 'Texto Sentencia __[]__ Url Sentencia' -->
<xsl:template name="generar_nodos_derechos">
    <xsl:choose>
        <xsl:when test="count(marc:datafield[@tag='variable' and starts-with(./marc:subfield[@code='n'],'textoUrlDerechos_') and string-length(normalize-space(marc:subfield[@code='v']))>0])>0">
            <xsl:for-each select="marc:datafield[@tag='variable' and starts-with(./marc:subfield[@code='n'],'textoUrlDerechos_') and string-length(normalize-space(marc:subfield[@code='v']))>0]">
                <xsl:variable name="textoDerechos">
                    <xsl:value-of select="substring-before(marc:subfield[@code='v'],'__[]__')"/>
                </xsl:variable>
                <xsl:if test="string-length(normalize-space($textoDerechos))>0">
                    <dc:rights>
                        <xsl:value-of select="normalize-space($textoDerechos)"/>
                    </dc:rights>
                </xsl:if>
            </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
            <xsl:for-each select="marc:datafield[@tag='542']">
                <xsl:variable name="campo542">
                    <xsl:call-template name="valor_campo_marc">
                        <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                        <xsl:with-param name="subcampos" select="'ac'" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:if test="string-length(normalize-space($campo542))>0">
                    <dc:rights><xsl:value-of select="$campo542"/></dc:rights>
                </xsl:if>            
            </xsl:for-each>
            <xsl:for-each select="marc:datafield[@tag='506']">
                <xsl:variable name="campo506">
                    <xsl:call-template name="valor_campo_marc">
                        <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                        <xsl:with-param name="subcampos" select="'3ade'" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:if test="string-length(normalize-space($campo506))>0">
                    <dc:rights><xsl:value-of select="$campo506"/></dc:rights>
                </xsl:if>            
            </xsl:for-each>
            <xsl:for-each select="marc:datafield[@tag='540']">
                <xsl:variable name="campo540">
                    <xsl:call-template name="valor_campo_marc">
                        <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                        <xsl:with-param name="subcampos" select="'3acd'" />
                    </xsl:call-template>
                </xsl:variable>
                <xsl:if test="string-length(normalize-space($campo540))>0">
                    <dc:rights><xsl:value-of select="$campo540"/></dc:rights>
                </xsl:if>            
            </xsl:for-each>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>


<!-- Una fecha ser vlida cuando tenga 4 caracteres y su primer y segundo caracter sean nmeros -->
<xsl:template name="is_fecha_valida">
    <xsl:param name="fecha" />
    
    <xsl:choose>
        <xsl:when test="string-length($fecha)=4 and 
            string-length(translate(substring($fecha, 1, 1),'1234567890',''))=0 and 
            string-length(translate(substring($fecha, 2, 1),'1234567890',''))=0">true</xsl:when>
        <xsl:otherwise>false</xsl:otherwise>
    </xsl:choose>
</xsl:template>
<!-- Se cambian los caracteres desconocidos (todo lo que no sea numero) de una fecha por ? -->
<xsl:template name="transformar_fecha_desconocida">
    <xsl:param name="fecha" />
    
    <xsl:if test="string-length($fecha)=4">
        <xsl:choose>
            <xsl:when test="string-length(translate(substring($fecha, 1, 1),'1234567890',''))!=0">?</xsl:when>
            <xsl:otherwise><xsl:value-of select="substring($fecha, 1, 1)"/></xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length(translate(substring($fecha, 2, 1),'1234567890',''))!=0">?</xsl:when>
            <xsl:otherwise><xsl:value-of select="substring($fecha, 2, 1)"/></xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length(translate(substring($fecha, 3, 1),'1234567890',''))!=0">?</xsl:when>
            <xsl:otherwise><xsl:value-of select="substring($fecha, 3, 1)"/></xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length(translate(substring($fecha, 4, 1),'1234567890',''))!=0">?</xsl:when>
            <xsl:otherwise><xsl:value-of select="substring($fecha, 4, 1)"/></xsl:otherwise>
        </xsl:choose>        
    </xsl:if>
</xsl:template>

<xsl:template name="obtener_fecha_008">
    <xsl:variable name="fecha008" select="substring(marc:controlfield[@tag=008],8,4)" />
    <xsl:variable name="digito1y2" select="substring($fecha008, 1, 2)" />
    <xsl:variable name="digito3" select="substring($fecha008, 3, 1)" />
    <xsl:variable name="digito4" select="substring($fecha008, 4, 1)" />

    <!-- Slo se pondr el nodo date si hay 4 digitos en el 008 y los dos dgitos primeros del 008 son numeros-->
    <xsl:if test="string-length($fecha008)=4 and string-length(translate($digito1y2,'1234567890',''))=0">
        <xsl:choose>
            <!-- Si el dgito 3 no es un nmero o est vacio, se pone la dcada por defecto completa -->
            <xsl:when test="string-length(translate($digito3,'1234567890',''))!=0 or string-length(normalize-space($digito3))=0">
                <xsl:value-of select="concat($digito1y2,'',$decada_defecto)"/>
            </xsl:when>
            
            <!--  Si el digito 4 no es un nmero o est vacio, se pone slo el ltimo dgito por defecto -->
            <xsl:when test="string-length(translate($digito4,'1234567890',''))!=0 or string-length(normalize-space($digito4))=0">
                <xsl:value-of select="concat($digito1y2,$digito3,$anyo_defecto)"/>
            </xsl:when>
            
            <!--  Si llega aqu, los 4 dgitos son nmeros y se pone la fecha tal cual -->
            <xsl:otherwise>
                <xsl:value-of select="$fecha008"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:if>
</xsl:template>

<!-- Template parte la cadena de tipos y genera un nodo
type por cada uno siempre que no est repetido. -->  
<xsl:template name="genera_nodos_type655">
    <xsl:param name="tipos_655" />
    <xsl:param name="separador" />

    <xsl:choose>
        <!-- Si la lista de nodos contiene el separador significa 
        que hay que seguir partiendo -->
        <xsl:when test="contains($tipos_655,$separador)">
            <!-- Se saca lo que hay antes y despus del primer separador -->
            <xsl:variable name="tipoAntes" select="substring-before($tipos_655,$separador)"/>
            <xsl:variable name="restoTipos" select="substring-after($tipos_655,$separador)"/>
        
            <!-- Se crea un nodo con el texto de antes -->
            <xsl:if test="not(contains($restoTipos, $tipoAntes))">
                <dc:type><xsl:value-of select="normalize-space($tipoAntes)"/></dc:type>
            </xsl:if>
            <!-- Se llama recursivamente al template para seguir gestionando
            el resto de la lista -->
            <xsl:call-template name="genera_nodos_type655">
                <xsl:with-param name="tipos_655" select="$restoTipos" />
                <xsl:with-param name="separador" select="$separador" />
            </xsl:call-template>    
        </xsl:when>
        <!-- Si la lista de nodos no contiene el separador significa
        que no hay que seguir separando y se pone el nodo tal cual -->
        <xsl:otherwise>
            <xsl:if test="string-length(normalize-space($tipos_655)) > 0">
                <dc:type><xsl:value-of select="normalize-space($tipos_655)"/></dc:type>            
            </xsl:if>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- Devuelve true si alguno de los nodos del 655 pasado se corresponde
con el del tipo_ldr pasado -->  
<xsl:template name="comprueba_655_contiene_LDR">
    <xsl:param name="tipos_655" />
    <xsl:param name="separador" />
    <xsl:param name="tipo_ldr" />
    
    <xsl:choose>
        <!-- Si la lista de nodos contiene el separador significa 
        que hay que seguir partiendo -->
        <xsl:when test="contains($tipos_655,$separador)">
            <!-- Se saca lo que hay antes y despus del primer separador -->
            <xsl:variable name="tipo_antes" select="substring-before($tipos_655,$separador)"/>
            <xsl:variable name="restoTipos" select="substring-after($tipos_655,$separador)"/>

            <!-- Se comprueba si coincide. Si coincide, se acab -->
            <xsl:choose>
                <xsl:when test="contains($tipo_antes,$tipo_ldr) and 
                    string-length(normalize-space($tipo_antes)) = string-length(normalize-space($tipo_ldr))">
                    true
                </xsl:when>
                <xsl:otherwise>
                    <!-- Se llama recursivamente al template para seguir gestionando
                    el resto de la lista -->
                    <xsl:call-template name="comprueba_655_contiene_LDR">
                        <xsl:with-param name="tipos_655" select="$restoTipos" />
                        <xsl:with-param name="separador" select="$separador" />
                        <xsl:with-param name="tipo_ldr" select="$tipo_ldr" />
                    </xsl:call-template>            
                </xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        <!-- Si la lista de nodos no contiene el separador significa
        que no hay que seguir separando y se comprueba si concuerda -->
        <xsl:otherwise>
            <xsl:choose>
                <xsl:when test="string-length(normalize-space($tipos_655))>0 and 
                string-length(translate($tipos_655, $tipo_ldr, '')) = 0">
                    true
                </xsl:when>
                <xsl:otherwise>
                    false
                </xsl:otherwise>
            </xsl:choose>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- Devuelve una lista de tipos de documentos asociados al 655 separados por el caracter pasado -->
<xsl:template name="get_lista_tipos_conocidos_655">
    <xsl:param name="separador" />
    <xsl:param name="tipo_ldr" />

    <!-- Se sacan todos los nodos del 655 separados por el objeto separador -->
    <xsl:for-each select="marc:datafield[@tag='655']">
        <!-- Se saca el tipo mapeado a driver 2.0 -->
        <xsl:variable name="type655">
            <xsl:call-template name="get_tipo_version_2">
                <xsl:with-param name="tipo" select="./marc:subfield[@code='a']" />
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="type655_lower">
            <xsl:call-template name="lowercase">
                <xsl:with-param name="cadena" select="$type655" />
            </xsl:call-template>
        </xsl:variable>
        
        <!-- Slo se considerarn una serie de tipos prefijados y siempre que no coincida
        con el texto sacado del ldr cuando es driver -->
        <xsl:choose>
            <xsl:when test="$driver='true'">
                <xsl:choose>
                    <xsl:when test="($type655_lower = 'article' or $type655_lower = 'bachelorthesis' or 
                            $type655_lower = 'masterthesis' or $type655_lower = 'doctoralthesis' or 
                            $type655_lower = 'book' or $type655_lower = 'bookpart' or 
                            $type655_lower = 'conferenceobject' or $type655_lower = 'lecture' or 
                            $type655_lower = 'preprint or workingpaper' or $type655_lower = 'report' or 
                            $type655_lower = 'contributiontoperiodical' or $type655_lower = 'review' or 
                            $type655_lower = 'annotation' or $type655_lower = 'patent') and 
                            $type655_lower != $tipo_ldr">
                            <xsl:value-of select="$type655"/>
                            <xsl:value-of select="$separador"/>
                    </xsl:when>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="valor_campo_marc">
                    <xsl:with-param name="estructura_campo" select="$nodos_estructura_campos[tag=current()/@tag]" />
                </xsl:call-template>
                <xsl:value-of select="$separador"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:for-each>
</xsl:template>

<!-- Transforma el 655 versin driver 1.0 a driver 2.0 -->
<xsl:template name="get_tipo_version_2">
    <xsl:param name="tipo" />
    
    <xsl:variable name="tipo_lower">
        <xsl:call-template name="lowercase">
            <xsl:with-param name="cadena" select="normalize-space($tipo)" />
        </xsl:call-template>
    </xsl:variable>
            
    <xsl:choose>
        <!-- 1.0 to 2.0 -->
        <xsl:when test="$tipo_lower='article'">article</xsl:when>
        <xsl:when test="$tipo_lower='bachelor thesis'">bachelorThesis</xsl:when>
        <xsl:when test="$tipo_lower='master thesis'">masterThesis</xsl:when>
        <xsl:when test="$tipo_lower='doctoral thesis'">doctoralThesis</xsl:when>
        <xsl:when test="$tipo_lower='book'">book</xsl:when>
        <xsl:when test="$tipo_lower='part of book or chapter of book'">bookPart</xsl:when>
        <xsl:when test="$tipo_lower='conference lecture'">conferenceObject</xsl:when>
        <xsl:when test="$tipo_lower='conference report'">conferenceObject</xsl:when>
        <xsl:when test="$tipo_lower='lecture'">lecture</xsl:when>
        <xsl:when test="$tipo_lower='research paper'">preprint or workingPaper</xsl:when>
        <xsl:when test="$tipo_lower='external research report'">report</xsl:when>
        <xsl:when test="$tipo_lower='internal report'">report</xsl:when>
        <xsl:when test="$tipo_lower='contribution for newspaper or weekly magazine'">contributionToPeriodical</xsl:when>
        <xsl:when test="$tipo_lower='newsletter'">contributionToPeriodical</xsl:when>
        
        <!-- 2.0 -->
        <xsl:when test="$tipo_lower='article'">article</xsl:when>
        <xsl:when test="$tipo_lower='bachelorthesis'">bachelorThesis</xsl:when>
        <xsl:when test="$tipo_lower='masterthesis'">masterThesis</xsl:when>
        <xsl:when test="$tipo_lower='doctoralthesis'">doctoralThesis</xsl:when>
        <xsl:when test="$tipo_lower='book'">book</xsl:when>
        <xsl:when test="$tipo_lower='bookpart'">bookPart</xsl:when>
        <xsl:when test="$tipo_lower='conferenceobject'">conferenceObject</xsl:when>
        <xsl:when test="$tipo_lower='lecture'">lecture</xsl:when>
        <xsl:when test="$tipo_lower='preprint or workingpaper'">preprint or workingPaper</xsl:when>
        <xsl:when test="$tipo_lower='report'">report</xsl:when>
        <xsl:when test="$tipo_lower='contributionToPeriodical'">contributiontoperiodical</xsl:when>
                
        <xsl:otherwise><xsl:value-of select="$tipo_lower"/></xsl:otherwise>
    </xsl:choose>
</xsl:template>    

<!-- Devuelve el tipo de documento a travs del ldr -->
<xsl:template name="get_tipo_conocido_ldr">
    <xsl:param name="leader6" />
    <xsl:param name="leader7" />
    
    <xsl:choose>
        <!-- Monografa -->
        <xsl:when test="string-length(translate($leader6, 'a', '')) = 0 and 
                    string-length(translate($leader7, 'cdm', '')) = 0">book</xsl:when>

        <!-- Analtica de Monografa, Captulo de libros -->
        <xsl:when test="string-length(translate($leader7, 'a', '')) = 0">bookPart</xsl:when>

        <!-- Analtica de Seriada, Artculos, Nmeros -->
        <xsl:when test="string-length(translate($leader7, 'b', '')) = 0">
            <xsl:variable name="esNumero">
                <xsl:call-template name="es_numero" />
            </xsl:variable>
            <xsl:choose>
                <xsl:when test="$esNumero = 'true'">other</xsl:when>
                <xsl:otherwise>article</xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        
        <xsl:otherwise>other</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- Devuelve el tipo de documento a travs del ldr para el formato ESE -->
<xsl:template name="get_tipo_europeana_ldr">
    <xsl:param name="leader6" />
    <xsl:param name="leader7" />
    <xsl:param name="formatos" />
    
    <!-- Sacamos si es nmero -->
    <xsl:variable name="esNumero">
        <xsl:call-template name="es_numero" />
    </xsl:variable>
    
    <!-- Se saca el primer tipo mime -->
    <xsl:variable name="tipo_mime">
        <xsl:choose>
            <xsl:when test="count($formatos)=1">
                <xsl:value-of select="normalize-space($formatos)"/>
            </xsl:when>
            <xsl:when test="count($formatos)>1">
                <xsl:value-of select="normalize-space($formatos[1])"/>
            </xsl:when>
        </xsl:choose>
    </xsl:variable>    
    
    <!-- Se saca el tipo del registro -->
    <xsl:variable name="bib_tipo">
        <xsl:call-template name="bib_tipo_publicacion_id"/>
    </xsl:variable>

    <xsl:choose>
        <!-- TEXT (libros + revistas + capitulos + artculos + nmeros + manuscritos -->
        <xsl:when test="$bib_tipo='monografia' or $bib_tipo='seriada' or 
            $bib_tipo='analitica_monografia' or $bib_tipo='analitica_seriada'
            or $bib_tipo='numero' or $bib_tipo='manuscrito'">TEXT</xsl:when>
        <!-- TEXT (partituras) -->
        <xsl:when test="$bib_tipo='musica'">TEXT</xsl:when>
        <!-- IMAGE (mapas + ilustraciones) -->
        <xsl:when test="$bib_tipo='mapa' or $bib_tipo='visual'">IMAGE</xsl:when>
        <!-- SOUND (materiales sonoros) -->
        <xsl:when test="$bib_tipo='sonoro'">SOUND</xsl:when>
        <!-- El resto, lo que diga el mimetipe -->
        <xsl:otherwise>
            <xsl:choose>
                <xsl:when test="starts-with($tipo_mime,'image')">IMAGE</xsl:when>
                <xsl:when test="starts-with($tipo_mime,'video')">VIDEO</xsl:when>
                <xsl:when test="starts-with($tipo_mime,'audio')">SOUND</xsl:when>
                <!-- En cualquier otro caso, y por defecto, se pone TEXT -->
                <xsl:otherwise>TEXT</xsl:otherwise>
            </xsl:choose>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- Template que devuelve la cadena en minsculas -->
<xsl:template name="lowercase">
    <xsl:param name="cadena" />
    <xsl:value-of select="translate($cadena, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')"/>
</xsl:template>

<!-- Template que devuelve la cadena en maysculas -->
<xsl:template name="uppercase">
    <xsl:param name="cadena" />
    <xsl:value-of select="translate($cadena, 'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
</xsl:template>

<!-- Template parte la cadena de lenguajes pasados y genera un nodo
language por cada uno. No lo escribe si es igual al lenguaje que ya se 
pasa por parametro -->
<xsl:template name="genera_nodos_language">
    <xsl:param name="cadena_idiomas" />
    <xsl:param name="longitud_idioma" />
    <xsl:param name="idiomas_repetidos" />
    <xsl:param name="linked_data"/>    
    <xsl:param name="europeana"/>
 
    <!-- Si la cadena de idiomas tiene una longitud superior a $longitud_idioma es que contiene 
         ms de un idioma y por tanto la vamos partiendo en trozos de longitud $longitud_idioma, 
         para generar un nodo language por cada uno -->
    <xsl:variable name="idioma">
        <xsl:choose>
            <xsl:when test="string-length($cadena_idiomas)>$longitud_idioma">
                <xsl:value-of select="substring($cadena_idiomas,1,$longitud_idioma)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$cadena_idiomas"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <!-- Slo generamos nodo dc:language para el idioma si no est entre los idiomas repetidos -->
    <xsl:if test="not(contains($idiomas_repetidos, $idioma))">
        <xsl:choose>
            <!-- Si se trata de un formato de Europeana o ms concretamente de EDM, se genera un dc:language
                 sin enlace-->
            <xsl:when test="($europeana='true' or $EDM) and $correspondencia_idioma/codigo[@origen=$idioma]">
                <dc:language>
                    <xsl:value-of select="$idioma"/>
                </dc:language>                
            </xsl:when>
            <!-- Si es linked data, los idiomas se generan como links y no como valor -->
            <xsl:when test="$linked_data='true' and $correspondencia_idioma/codigo[@origen=$idioma]">
                <dc:language rdf:resource="http://id.loc.gov/vocabulary/iso639-2/{$idioma}" />
            </xsl:when>
            <!-- Si no hay correspondencia en ISO639 lo marcamos como undefined-->                    
            <xsl:when test="($europeana='true' or $EDM) and not($correspondencia_idioma/codigo[@origen=$idioma])">
                <dc:language><xsl:text>und</xsl:text></dc:language>
            </xsl:when>
            <!-- En cualquier otro caso generamos un dc:language con el valor que nos llegue -->
            <xsl:otherwise>            
                <dc:language>
                    <xsl:value-of select="$idioma"/>
                </dc:language>                
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:if>

    <!-- Si la cadena de idiomas contena ms de un idioma volvemos a llamar al template con el resto
         de la cadena-->
    <xsl:if test="string-length($cadena_idiomas)>$longitud_idioma">    
        <xsl:call-template name="genera_nodos_language">
            <xsl:with-param name="cadena_idiomas" select="substring($cadena_idiomas,4)" />
            <xsl:with-param name="longitud_idioma" select="$longitud_idioma" />
            <xsl:with-param name="idiomas_repetidos" select="concat(concat($idiomas_repetidos, '-'), $idioma)" />
            <xsl:with-param name="linked_data" select="$linked_data" />
            <xsl:with-param name="europeana" select="$europeana" />
        </xsl:call-template>
    </xsl:if>
    
</xsl:template>

<!-- 
    Comprueba si la fecha pasada es del tipo:
    YYYY-1(2)m-1(2)d
    1(2)d-1(2)m-yyyy
    YYYYMMdd
    YYYYMMd
-->
<xsl:template name="get_fecha_valida">
    <xsl:param name="fecha" />

    <xsl:variable name="tamano" select="string-length($fecha)" />
    
    <xsl:choose>
        <!--  formatos YYYYMMd o YYYYMMdd -->
        <xsl:when test="string-length(translate($fecha,'1234567890',''))=0">
            <xsl:choose>
                <xsl:when test="$tamano = 7 or $tamano = 8">
                    <xsl:variable name="anyo" select="substring($fecha, 1, 4)" />
                    <xsl:variable name="mes" select="substring($fecha, 5, 2)" />
                    <xsl:variable name="dia" select="substring($fecha, 7)" />
                    <xsl:choose>
                        <xsl:when test="$mes &lt; 1 or $mes &gt; 12 or $dia &lt; 1 or $dia &gt; 31">
                            n
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="componer_fecha">
                                <xsl:with-param name="anyo" select="$anyo" />
                                <xsl:with-param name="mes" select="$mes" />
                                <xsl:with-param name="dia" select="$dia" />                                
                            </xsl:call-template>                        
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:otherwise>n</xsl:otherwise>
            </xsl:choose>
        </xsl:when>
        
        <!--  formatos YYYY-1(2)m-1(2)d o 1(2)d-1(2)m-yyyy -->
        <xsl:otherwise>
            <xsl:variable name="grupo1" select="substring-before($fecha,'-')" />
            <xsl:variable name="grupo2" select="substring-before(substring-after($fecha,'-'),'-')" />
            <xsl:variable name="grupo3" select="substring-after(substring-after($fecha,'-'),'-')" />
            <xsl:variable name="grupo1a" select="substring-before($fecha,'/')" />
            <xsl:variable name="grupo2a" select="substring-before(substring-after($fecha,'/'),'/')" />
            <xsl:variable name="grupo3a" select="substring-after(substring-after($fecha,'/'),'/')" />
            
            <xsl:choose>
                <!--  Su alguno de los trozos no es un numero, no es vlido -->
                <xsl:when test="string-length(translate($grupo1,'1234567890','')) > 0 or 
                                string-length(translate($grupo2,'1234567890','')) > 0 or 
                                string-length(translate($grupo3,'1234567890','')) > 0 or
                                string-length(translate($grupo1a,'1234567890','')) > 0 or
                                string-length(translate($grupo2a,'1234567890','')) > 0 or
                                string-length(translate($grupo3a,'1234567890','')) > 0">
                    n
                </xsl:when>
                <!--  formatos YYYY-1(2)m-1(2)d -->
                <xsl:when test="string-length($grupo1) = 4 and 
                                (string-length($grupo2) = 1 or string-length($grupo2) = 2) and 
                                (string-length($grupo3) = 1 or string-length($grupo3) = 2) and 
                                not($grupo2 &lt; 1 or $grupo2 &gt; 12 or $grupo3 &lt; 1 or $grupo3 &gt; 31 or $grupo1 = 0)">
                    <xsl:call-template name="componer_fecha">
                        <xsl:with-param name="anyo" select="$grupo1" />
                        <xsl:with-param name="mes" select="$grupo2" />
                        <xsl:with-param name="dia" select="$grupo3" />                                
                    </xsl:call-template>                        
                </xsl:when>
                <!--  formatos YYYY/1(2)m/1(2)d -->
                <xsl:when test="string-length($grupo1a) = 4 and 
                                (string-length($grupo2a) = 1 or string-length($grupo2a) = 2) and 
                                (string-length($grupo3a) = 1 or string-length($grupo3a) = 2) and 
                                not($grupo2a &lt; 1 or $grupo2a &gt; 12 or $grupo3a &lt; 1 or $grupo3a &gt; 31 or $grupo1a = 0)">
                    <xsl:call-template name="componer_fecha">
                        <xsl:with-param name="anyo" select="$grupo1a" />
                        <xsl:with-param name="mes" select="$grupo2a" />
                        <xsl:with-param name="dia" select="$grupo3a" />                                
                    </xsl:call-template>                        
                </xsl:when>
                
                <!--  formatos 1(2)d-1(2)m-yyyy -->
                <xsl:when test="(string-length($grupo1) = 1 or string-length($grupo1) = 2) and 
                                (string-length($grupo2) = 1 or string-length($grupo2) = 2) and 
                                string-length($grupo3) = 4 and
                                not($grupo2 &lt; 1 or $grupo2 &gt; 12 or $grupo1 &lt; 1 or $grupo1 &gt; 31 or $grupo3 = 0)">
                    <xsl:call-template name="componer_fecha">
                        <xsl:with-param name="anyo" select="$grupo3" />
                        <xsl:with-param name="mes" select="$grupo2" />
                        <xsl:with-param name="dia" select="$grupo1" />                                
                    </xsl:call-template>                        
                </xsl:when>
                <!--  formatos 1(2)d-1(2)m-yyyy -->
                <xsl:when test="(string-length($grupo1a) = 1 or string-length($grupo1a) = 2) and 
                                (string-length($grupo2a) = 1 or string-length($grupo2a) = 2) and 
                                string-length($grupo3a) = 4 and
                                not($grupo2a &lt; 1 or $grupo2a &gt; 12 or $grupo1a &lt; 1 or $grupo1a &gt; 31 or $grupo3a = 0)">
                    <xsl:call-template name="componer_fecha">
                        <xsl:with-param name="anyo" select="$grupo3a" />
                        <xsl:with-param name="mes" select="$grupo2a" />
                        <xsl:with-param name="dia" select="$grupo1a" />                                
                    </xsl:call-template>                        
                </xsl:when>
                <xsl:otherwise>n</xsl:otherwise>
            </xsl:choose>
        </xsl:otherwise>
    </xsl:choose>        
</xsl:template>

<!--  -->
<xsl:template name="componer_fecha">
    <xsl:param name="anyo" />
    <xsl:param name="mes" />
    <xsl:param name="dia" />
    
    <xsl:choose>
        <!--  Su alguno de los trozos no es un numero, no es vlido -->
        <xsl:when test="string-length($dia) = 1 and string-length($mes) = 1"> 
            <xsl:value-of select="$anyo"/>
            <xsl:text>-0</xsl:text>
            <xsl:value-of select="$mes"/>
            <xsl:text>-0</xsl:text>
            <xsl:value-of select="$dia"/>
        </xsl:when>
        <xsl:when test="string-length($dia) = 1 and string-length($mes) = 2"> 
            <xsl:value-of select="$anyo"/>
            <xsl:text>-</xsl:text>
            <xsl:value-of select="$mes"/>
            <xsl:text>-0</xsl:text>
            <xsl:value-of select="$dia"/>
        </xsl:when>
        <xsl:when test="string-length($dia) = 2 and string-length($mes) = 1"> 
            <xsl:value-of select="$anyo"/>
            <xsl:text>-0</xsl:text>
            <xsl:value-of select="$mes"/>
            <xsl:text>-</xsl:text>
            <xsl:value-of select="$dia"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$anyo"/>
            <xsl:text>-</xsl:text>
            <xsl:value-of select="$mes"/>
            <xsl:text>-</xsl:text>
            <xsl:value-of select="$dia"/>
        </xsl:otherwise>
    </xsl:choose>
    
</xsl:template>    

<xsl:template name="procesar_grupo_dc">
	<xsl:param name="tipo" />
	<xsl:param name="valor" />
	<xsl:param name="params" />

    <!-- Se controla que no se meta por aqu si es dc normal y no tiene nodo dublin core normal (que haya algo delante de :) -->
	<xsl:call-template name="principio_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
	<xsl:value-of select="$valor" disable-output-escaping="yes" />
	<xsl:call-template name="fin_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
	<xsl:call-template name="eol" />
</xsl:template>


<xsl:template name="separador_grupo_dc">
	<xsl:param name="tipo" />
	
	<xsl:call-template name="fin_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
	<xsl:call-template name="eol" />
	<xsl:call-template name="principio_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
</xsl:template>
	
	
<xsl:template name="principio_nodo">
	<xsl:param name="tipo" />
    
	<xsl:text disable-output-escaping="yes">&lt;</xsl:text>
	<xsl:call-template name="nombre_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
	<xsl:call-template name="atributo_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
    
<!--
    <xsl:if test="$dc_cualificado='true' and contains($tipo,':') and not($EDM)">
        <xsl:text> xmlns:dcterms="http://purl.org/dc/terms/"</xsl:text>
    </xsl:if>


	<xsl:text disable-output-escaping="yes">&gt;</xsl:text>
-->
    
</xsl:template>

	
<xsl:template name="fin_nodo">
	<xsl:param name="tipo" />

<!--    
	<xsl:text disable-output-escaping="yes">&lt;/</xsl:text>
	<xsl:call-template name="nombre_nodo">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
	<xsl:text disable-output-escaping="yes">&gt;</xsl:text>
-->
</xsl:template>
	

<xsl:template name="nombre_nodo">
	<xsl:param name="tipo" />

    <xsl:variable name="tipo2">
        <xsl:if test="starts-with($tipo, 'link:')">
            <xsl:value-of select="substring-after($tipo, ':')" />
        </xsl:if>
        <xsl:if test="not(starts-with($tipo, 'link:'))">
            <xsl:value-of select="$tipo" />
        </xsl:if>
    </xsl:variable>
    
    <xsl:choose>
    
        <!-- En EDM, salvo el isPartOf va sin dcterms -->
<!--
        <xsl:when test="$dc_cualificado='true' and contains($tipo,':') and $EDM='true' 
            and substring-after($tipo, ':')!='isPartOf'">
            <xsl:value-of select="substring-after($tipo, ':')" />
        </xsl:when>
-->
        <xsl:when test="$DC_CUALIFICADO and contains($tipo2,':')">
            <xsl:text>dcterms:</xsl:text>
            <xsl:value-of select="substring-after($tipo2, ':')" />
        </xsl:when>
        <xsl:when test="contains($tipo2,':')">
            <xsl:text>dc:</xsl:text>
            <xsl:value-of select="substring-before($tipo2, ':')" />
        </xsl:when>
        <xsl:otherwise>
            <xsl:text>dc:</xsl:text>
            <xsl:value-of select="$tipo2" />
        </xsl:otherwise>
    </xsl:choose>

<!--      
	<xsl:choose>
		<xsl:when test="contains($tipo, ':')">
			<xsl:value-of select="substring-before($tipo, ':')" />
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$tipo" />
		</xsl:otherwise>
	</xsl:choose>
-->
</xsl:template>

<xsl:template name="atributo_nodo">
	<xsl:param name="tipo" />

<!-- Procesamiento para Dublin core qualified. An no se genera este tipo de DC, as que por ahora se deja comentado -->
<!-- 
	<xsl:if test="contains($tipo, ':')">
		<xsl:variable name="atrib_valor" select="substring-after($tipo, ':')" />
		<xsl:variable name="atrib" select="substring-before($atrib_valor, ':')" />
		<xsl:variable name="valor" select="substring-after($atrib_valor, ':')" />

		<xsl:text> </xsl:text>
		<xsl:value-of select="$atrib" />
		<xsl:text>="</xsl:text>
		<xsl:value-of select="$valor" />
		<xsl:text>"</xsl:text>
	</xsl:if>
-->
</xsl:template>

<xsl:template name="valor_grupo_dc">
	<xsl:param name="tipo" />
	<xsl:param name="valor" />
	<xsl:param name="posicion_grupo" />
	<xsl:param name="num_valores_grupo" />
	<xsl:param name="nodo_registro" />
	<xsl:param name="nodo_campo" />

	<!-- Link: nmero de control -->
	<xsl:variable name="valor_link" select="
            starts-with($tipo, 'link:') and $EDM
            and ($nodo_campo/marc:subfield[@code='0' or @code='w'])" />

	<xsl:if test="$valor_link">
    	<xsl:text disable-output-escaping="yes"> rdf:resource=&quot;</xsl:text>
        <xsl:value-of select="$URL_BASE" />
    	<xsl:if test="$nodo_campo/marc:subfield[@code='0']">
    	   <xsl:text>aut/</xsl:text>
    	   <xsl:value-of select="$nodo_campo/marc:subfield[@code='0']" />
    	</xsl:if>
    	<xsl:if test="not($nodo_campo/marc:subfield[@code='0'])">
    	   <xsl:text>bib/</xsl:text>
    	   <xsl:value-of select="$nodo_campo/marc:subfield[@code='w']" />
    	</xsl:if>
    	<xsl:text disable-output-escaping="yes">&quot; /&gt;</xsl:text>
   	</xsl:if>
	
	<!-- Si no, valor vlido XML -->
	<xsl:if test="not($valor_link)">
        <xsl:text disable-output-escaping="yes">&gt;</xsl:text>
    	
    	<xsl:variable name="amp"><xsl:text>&amp;</xsl:text></xsl:variable>
    	<xsl:variable name="lt"><xsl:text>&lt;</xsl:text></xsl:variable>
    	<xsl:variable name="gt"><xsl:text>&gt;</xsl:text></xsl:variable>
    	<xsl:variable name="quot"><xsl:text>"</xsl:text></xsl:variable>
    	<xsl:variable name="apos"><xsl:text>&apos;</xsl:text></xsl:variable>
    	
    	<xsl:variable name="valorOk1">
    		<xsl:call-template name="replace">
    			<xsl:with-param name="texto" select="$valor" />
    			<xsl:with-param name="cadena1" select="$amp" />
    			<xsl:with-param name="cadena2" select="'&amp;amp;'" />
    		</xsl:call-template>
    	</xsl:variable>		
    	<xsl:variable name="valorOk2">
    		<xsl:call-template name="replace">
    			<xsl:with-param name="texto" select="$valorOk1" />
    			<xsl:with-param name="cadena1" select="$lt" />
    			<xsl:with-param name="cadena2" select="'&amp;lt;'" />
    		</xsl:call-template>
    	</xsl:variable>		
    	<xsl:variable name="valorOk3">
    		<xsl:call-template name="replace">
    			<xsl:with-param name="texto" select="$valorOk2" />
    			<xsl:with-param name="cadena1" select="$gt" />
    			<xsl:with-param name="cadena2" select="'&amp;gt;'" />
    		</xsl:call-template>
    	</xsl:variable>		
    	<xsl:variable name="valorOk4">
    		<xsl:call-template name="replace">
    			<xsl:with-param name="texto" select="$valorOk3" />
    			<xsl:with-param name="cadena1" select="$quot" />
    			<xsl:with-param name="cadena2" select="'&quot;'" />
    		</xsl:call-template>
    	</xsl:variable>	
    	<xsl:variable name="valorOk5">
    		<xsl:call-template name="replace">
    			<xsl:with-param name="texto" select="$valorOk4" />
    			<xsl:with-param name="cadena1" select="$apos" />
    			<xsl:with-param name="cadena2" select="'&amp;apos;'" />
    		</xsl:call-template>
    	</xsl:variable>	
    
    	<xsl:value-of select="$valorOk5"/>

    	<xsl:text disable-output-escaping="yes">&lt;/</xsl:text>
    	<xsl:call-template name="nombre_nodo">
    		<xsl:with-param name="tipo" select="$tipo" />
    	</xsl:call-template>
    	<xsl:text disable-output-escaping="yes">&gt;</xsl:text>
	</xsl:if>
</xsl:template>


<!-- Comprueba si el registro actual es un nmero de una publicacin peridica o no -->
<xsl:template name="es_numero">
    <xsl:variable name="idRegistro">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre">IdRegistro</xsl:with-param>
        </xsl:call-template>
    </xsl:variable>
    <xsl:choose>
        <xsl:when test="string-length($idRegistro)=10 and starts-with($idRegistro, '1')">true</xsl:when>
        <xsl:otherwise>false</xsl:otherwise>
    </xsl:choose>
</xsl:template> 

<!-- Devuelve true() si en la lista de variables, el valor de esta variable es la primera vez que aparece -->
<xsl:template name="valor_variable_aparece_primera_vez">
    <xsl:param name="nombre_variable"/>
    <xsl:param name="valor_variable"/>
    <xsl:param name="nodo"/>    

    <xsl:variable name="es_primera">    
        <xsl:for-each select="$nodo/../marc:datafield[@tag='variable' and ./marc:subfield[@code='v']=$valor_variable]">
            <xsl:choose>
                <xsl:when test="./marc:subfield[@code='n']=$nombre_variable and position()=1">
                    true
                </xsl:when>
                <xsl:otherwise>
                    false
                </xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:variable>

    <xsl:if test="starts-with(normalize-space($es_primera),'true')">
        true
    </xsl:if>    
</xsl:template>


<!--
    ** Template principal modificado para permitir relaciones **
    Muestra el valor de un campo MARC de acuerdo a la estructura definida.
    nodo_campo: Nodo con el campo MARC
    estructura_campo: Nodo con la puntuacin ISBD del campo
    tag_anterior: (opcional) Tag del campo que se escribe justo antes de este
    desde_subcampo: (opcional) Si aparece, cdigo de subcampo a partir del cual hay que empezar a poner el contenido del campo. Si no tiene el subcampo, no escribir nada
    hasta_subcampo: (opcional) Si aparece, cdigo de subcampo hasta el cual hay que poner el contenido del campo. Si no tiene el subcampo, escribir el campo completo
-->

<xsl:template name="valor_link_campo_marc">
    <xsl:param name="nodo_campo" select="current()" />
    <xsl:param name="estructura_campo" />
    <xsl:param name="tag_anterior" />
    <xsl:param name="subcampos" select="''" />
    <xsl:param name="ocultar_literales_campo" select="''" />
    <xsl:param name="link_campo" select="true()" />

    <!-- Nmeros de control de las autoridades relacionadas con autor titulo-->
    <xsl:variable name="ctrl_autoridad_principal">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre">
                <xsl:value-of select="$nodo_campo/marc:subfield[@code='0']"/>
                <xsl:text>_AUT2</xsl:text>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:variable>
        
    <!-- Se saca el enlace a la relacin, si lo hay -->
    <xsl:variable name="enlace_relacion">
        <xsl:choose>
            <!-- Primero se mira si es una relacin $0 del 100/110/111 (creator) o 700/710 (contributor) 
                y es autor titulo -->
            <xsl:when test="string-length($nodo_campo/marc:subfield[@code='0'])>0 and 
                ($nodo_campo/@tag='100' or $nodo_campo/@tag='110' or $nodo_campo/@tag='111' or
                 $nodo_campo/@tag='700' or $nodo_campo/@tag='710') and 
                string-length(normalize-space($ctrl_autoridad_principal))>0">
                <xsl:value-of select="$URL_BASE"/>
                <xsl:text>aut/</xsl:text>
                <xsl:value-of select="$ctrl_autoridad_principal"/>
            </xsl:when>
            <!-- Primero se mira si es una relacin $0 -->
            <xsl:when test="string-length($nodo_campo/marc:subfield[@code='0'])>0">
                <xsl:value-of select="$URL_BASE"/>
                <xsl:text>aut/</xsl:text>
                <xsl:value-of select="./marc:subfield[@code='0']"/>
            </xsl:when>
            <!-- Luego se mira si es una relacin $w de un 7XX-->
            <xsl:when test="string-length($nodo_campo/@tag)=3 and 
                (starts-with($nodo_campo/@tag,'76') or starts-with($nodo_campo/@tag,'77') or starts-with($nodo_campo/@tag,'78')) and
                string-length(normalize-space(./marc:subfield[@code='w']))>0">
                <xsl:value-of select="$URL_BASE"/>
                <xsl:text>bib/</xsl:text>
                <xsl:value-of select="./marc:subfield[@code='w']"/>
            </xsl:when>            
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="es_link" select="(string-length($enlace_relacion) > 0) and $EDM" />
    <xsl:if test="$es_link">
        <xsl:value-of select="$enlace_relacion" />
    </xsl:if>
    <xsl:if test="not($es_link)">
        <xsl:call-template name="valor_campo_marc">
            <xsl:with-param name="nodo_campo" select="$nodo_campo" />
            <xsl:with-param name="estructura_campo" select="$estructura_campo" />
            <xsl:with-param name="tag_anterior" select="$tag_anterior" />
            <xsl:with-param name="subcampos" select="$subcampos" />
            <xsl:with-param name="ocultar_literales_campo" select="$ocultar_literales_campo" />
            <xsl:with-param name="link_campo" select="$link_campo" />
        </xsl:call-template>
    </xsl:if>
</xsl:template>


<xsl:template name="check_norepetido">
    <xsl:param name="nodo_campo" />
    
    <!-- Se saca la autoridad principal a la que se est apuntando -->
    <xsl:variable name="nombre_variable_autor_titulo">
        <xsl:value-of select="$nodo_campo/marc:subfield[@code='0']"/>
        <xsl:text>_AUT2</xsl:text>                
    </xsl:variable>
    <xsl:variable name="ctrl_autoridad_principal">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre">
                <xsl:value-of select="$nombre_variable_autor_titulo"/>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:variable>

    <!-- Se mira qu nodos autores titulo apuntan a este autor -->
    <xsl:variable name="autores_titulo_iguales" select="
            $nodo_campo/../marc:datafield[
                @tag='variable'
                and ./marc:subfield[@code='v']=$ctrl_autoridad_principal
                ]" />                
    
    <xsl:choose>
        <!-- No es autor-ttulo, se pone -->
        <xsl:when test="string-length($ctrl_autoridad_principal) = 0">
            <xsl:text>OK</xsl:text>
        </xsl:when>

        <!-- Si slo hay uno, se pone directamente -->
        <xsl:when test="count($autores_titulo_iguales) &lt;= 1">
            <xsl:text>OK</xsl:text>
        </xsl:when>
        <!-- Si hay varios, slo si es el primero -->
        <xsl:when test="$autores_titulo_iguales[1]/marc:subfield[@code='n'] = $nombre_variable_autor_titulo">
            <xsl:text>OK</xsl:text>
        </xsl:when>
        
        <xsl:otherwise>
            <xsl:text>NO</xsl:text>
        </xsl:otherwise>
    </xsl:choose>

</xsl:template>


</xsl:stylesheet>
